<?php

declare(strict_types=1);

namespace Atk4\Ui\Demos;

use Atk4\Ui\Form;
use Atk4\Ui\JsToast;

/** @var \Atk4\Ui\App $app */
require_once __DIR__ . '/../init-app.php';

// Testing form.

// create header
\Atk4\Ui\Header::addTo($app, ['Database-driven form with an enjoyable layout']);

// create form
$form = Form::addTo($app, ['segment']);
//$form = Form::addTo($app, ['segment', 'buttonSave' => false]);
//$form = Form::addTo($app, ['segment', 'buttonSave' => new \Atk4\Ui\Button(['Import', 'secondary', 'iconRight' => 'list'])]);
//$form = Form::addTo($app, ['segment', 'buttonSave' => [null, 'Import', 'secondary', 'iconRight' => 'list']]);
\Atk4\Ui\Label::addTo($form, ['Input new country information here', 'top attached'], ['AboveControls']);

$form->setModel((new CountryLock($app->db))->createEntity(), []);

// form basic field group
$formAddress = $form->addGroup('Basic Country Information');
$name = $formAddress->addControl(Country::hinting()->fieldName()->name, ['width' => 'sixteen']);
$name->addAction(['Check Duplicate', 'iconRight' => 'search'])->on('click', function ($jQuery, $name) use ($app, $form) {
    if ((new CountryLock($app->db))->tryLoadBy(Country::hinting()->fieldName()->name, $name)->isLoaded()) {
        return $form->js()->form('add prompt', Country::hinting()->fieldName()->name, 'This country name is already added.');
    }

    return new JsToast('This country name can be added.');
}, ['args' => ['_n' => $name->jsInput()->val()]]);

// form codes field group
$formCodes = $form->addGroup(['Codes']);
$formCodes->addControl(Country::hinting()->fieldName()->iso, ['width' => 'four'])->iconLeft = 'flag';
$formCodes->addControl(Country::hinting()->fieldName()->iso3, ['width' => 'four'])->iconLeft = 'flag';
$formCodes->addControl(Country::hinting()->fieldName()->numcode, ['width' => 'four'])->iconLeft = 'flag';
$formCodes->addControl(Country::hinting()->fieldName()->phonecode, ['width' => 'four'])->iconLeft = 'flag';

// form names field group
$formNames = $form->addGroup(['More Information about you']);
$formNames->addControl('first_name', ['width' => 'five', 'caption' => 'First Name']);
$formNames->addControl('middle_name', ['width' => 'five', 'caption' => 'Middle Name']);
$formNames->addControl('last_name', ['width' => 'six', 'caption' => 'Last Name']);

// form on submit
$form->onSubmit(function (Form $form) {
    $countryEntity = (new CountryLock($form->getApp()->db))->createEntity();
    // Model will have some validation too
    foreach ($form->model->getFields('editable') as $k => $field) {
        if ($countryEntity->hasField($k)) {
            $countryEntity->set($k, $form->model->get($k));
        }
    }

    // In-form validation
    $errors = [];
    if (mb_strlen($form->model->get('first_name')) < 3) {
        $errors[] = $form->error('first_name', 'too short, ' . $form->model->get('first_name'));
    }
    if (mb_strlen($form->model->get('last_name')) < 5) {
        $errors[] = $form->error('last_name', 'too short');
    }

    // Model validation. We do it manually because we are not using Model::save() method in demo mode.
    foreach ($countryEntity->validate('save') as $k => $error) {
        $errors[] = $form->error($k, $error);
    }

    if ($errors) {
        return $errors;
    }

    return new JsToast($countryEntity->getUserAction('add')->execute());
});

// ======

/** @var \Atk4\Data\Model $personClass */
$personClass = AnonymousClassNameCache::get_class(fn () => new class() extends \Atk4\Data\Model {
    public $table = 'person';

    protected function init(): void
    {
        parent::init();
        $this->addField('name', ['required' => true]);
        $this->addField('surname', ['ui' => ['placeholder' => 'e.g. Smith']]);
        $this->addField('gender', ['enum' => ['M', 'F']]);
        $this->hasOne('country_lookup_id', ['model' => [Country::class]]); // this works fast
        $this->hasOne('country_dropdown_id', ['model' => [Country::class], 'ui' => ['form' => new Form\Control\Dropdown()]]); // this works slow
    }

    public function validate($intent = null): array
    {
        $errors = parent::validate();

        if ($this->get('name') === $this->get('surname')) {
            $errors['surname'] = 'Your surname cannot be same as the name';
        }

        return $errors;
    }
});

$form = Form::addTo($app)->addClass('segment');
$form->setModel((new $personClass($app->db))->createEntity());

$form->onSubmit(function ($form) {
    return new JsToast('Form saved!');
});
